package fr.lip6.move.pnml.framework.hlapi;

import org.apache.axiom.om.OMElement;
import org.eclipse.emf.common.util.DiagnosticChain;

import fr.lip6.move.pnml.framework.utils.IdRefLinker;
import fr.lip6.move.pnml.framework.utils.exception.InnerBuildException;
import fr.lip6.move.pnml.framework.utils.exception.InvalidIDException;
import fr.lip6.move.pnml.framework.utils.exception.VoidRepositoryException;

/**
 * This interface is for all HLAPI classes.
 * @author Guillaume Giffo
 *
 */
public interface HLAPIClass {

    /**
     *
     * @return the encapsulated object.
     */
    Object getContainedItem();

    /**
     * @return the string containing the pnml output.
     */
    String toPNML();

    /**
     *
     * Sets values to conform PNML document.
     *
     * @param subRoot
     *            the sub-tree to import.
     * @param idr
     *            an idreflinker to solve idref.
     * @exception InnerBuildException .
     * @exception InvalidIDException .
     * @exception VoidRepositoryException .
     */

    void fromPNML(OMElement subRoot, IdRefLinker idr)
            throws InnerBuildException, InvalidIDException,
            VoidRepositoryException;

    /**
     *
     * @param diagnostics
     *            for diagnostic informations.
     * @return true if there is no OCL violations
     */
    boolean validateOCL(DiagnosticChain diagnostics);
}
