/**
 *
 */
package fr.lip6.move.pnml.framework.utils;

import fr.lip6.move.pnml.framework.hlapi.HLAPIRootClass;

/**
 * An instance of registered model in model Repository.
 *
 * @author Guillaume Giffo
 *
 */
public class ModelRepositoryUnit {

    /**
     * This is the associated id repository, for id checking.
     */
    private final IdRepository idrep;

    /**
     * This is the associated PetriNetDoc of the document.
     */
    private HLAPIRootClass petriNetDoc;

    /**
     * This is the associated states for pretty printing XML doc.
     */
    private boolean prettyPrint;

    /**
     * This contains data for pretty printing.
     */
    private final PrettyPrintData ppd;

    /**
     * Default constructor.
     *
     * @param theIdrep
     *            the id repository
     * @param thePetriNetDoc
     *            the PetriNetDoc, root of the document
     */
    public ModelRepositoryUnit(IdRepository theIdrep,
            HLAPIRootClass thePetriNetDoc) {
        this.idrep = theIdrep;
        this.petriNetDoc = thePetriNetDoc;
        this.ppd = new PrettyPrintData();
    }

    /**
     * @return the idrep
     */
    public final IdRepository getIdrep() {
        return idrep;
    }

    /**
     * @param thePetriNetDoc
     *            the petriNetDoc to set
     */
    public final void setPetriNetDoc(HLAPIRootClass thePetriNetDoc) {
        this.petriNetDoc = thePetriNetDoc;
    }

    /**
     * @return the petriNetDoc
     */
    public final HLAPIRootClass getPetriNetDoc() {
        return petriNetDoc;
    }

    /**
     * @return the prettyPrint
     */
    public final boolean isPrettyPrint() {
        return prettyPrint;
    }

    /**
     * @param prettyPrintStatus
     *            the prettyPrint to set
     */
    public final void setPrettyPrint(boolean prettyPrintStatus) {
        this.prettyPrint = prettyPrintStatus;
    }

    /**
     *
     * @return A PrettyPrintData object
     */
    public final PrettyPrintData getPrettyPrinter() {
        return this.ppd;
    }

}
