/**
 * (C) University Pierre & Marie Curie - UMR CNRS 7606 (LIP6/MoVe)
 * All rights reserved.   This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *  
 *  Contributors: 
 *    Lom HILLAH (LIP6) - Initial models and implementation
 *    Rachid Alahyane (UPMC) - Infrastructure and continuous integration
 *    Bastien Bouzerau (UPMC) - Architecture
 *    Guillaume Giffo (UPMC)  - Code generation refactoring, high-level API
 *
 * $Id$
 */
package fr.lip6.move.pnml.symmetricnet.cyclicEnumerations.impl;

import java.util.Iterator;
import java.util.List;

import org.apache.axiom.om.OMElement;
import org.eclipse.emf.common.util.DiagnosticChain;
import org.eclipse.emf.ecore.EClass;

import fr.lip6.move.pnml.framework.utils.IdRefLinker;
import fr.lip6.move.pnml.framework.utils.ModelRepository;
import fr.lip6.move.pnml.framework.utils.PrettyPrintData;
import fr.lip6.move.pnml.framework.utils.exception.InnerBuildException;
import fr.lip6.move.pnml.framework.utils.exception.InvalidIDException;
import fr.lip6.move.pnml.framework.utils.exception.VoidRepositoryException;
import fr.lip6.move.pnml.symmetricnet.cyclicEnumerations.CyclicEnumeration;
import fr.lip6.move.pnml.symmetricnet.cyclicEnumerations.CyclicEnumerationsFactory;
import fr.lip6.move.pnml.symmetricnet.cyclicEnumerations.CyclicEnumerationsPackage;
import fr.lip6.move.pnml.symmetricnet.finiteEnumerations.FEConstant;
import fr.lip6.move.pnml.symmetricnet.finiteEnumerations.impl.FiniteEnumerationImpl;
import fr.lip6.move.pnml.symmetricnet.finiteEnumerations.impl.FiniteEnumerationsFactoryImpl;
import fr.lip6.move.pnml.symmetricnet.terms.Sort;
import fr.lip6.move.pnml.symmetricnet.terms.util.TermsValidator;

/**
 * <!-- begin-user-doc --> An implementation of the model object '
 * <em><b>Cyclic Enumeration</b></em>'. <!-- end-user-doc -->
 * <p>
 * </p>
 * 
 * @generated
 */
public class CyclicEnumerationImpl extends FiniteEnumerationImpl implements
		CyclicEnumeration {
	/**
	 * <!-- begin-user-doc --> <!-- end-user-doc -->
	 * 
	 * @generated
	 */
	protected CyclicEnumerationImpl() {
		super();
	}

	/**
	 * <!-- begin-user-doc --> <!-- end-user-doc -->
	 * 
	 * @generated
	 */
	@Override
	protected EClass eStaticClass() {
		return CyclicEnumerationsPackage.Literals.CYCLIC_ENUMERATION;
	}

	/**
	 * Return the string containing the pnml output
	 */
	public String toPNML() {
		// id 0
		// idref 0
		// attributes 0
		// sons 1

		Boolean prettyPrintStatus = ModelRepository.getInstance()
				.isPrettyPrintActive();
		String retline = "";
		String headline = "";
		PrettyPrintData prpd = null;
		if (prettyPrintStatus) {
			retline = "\n";
			prpd = ModelRepository.getInstance().getPrettyPrintData();
			headline = prpd.getCurrentLineHeader();
		}

		StringBuffer sb = new StringBuffer();
		sb.append(headline);
		sb.append("<cyclicenumeration");
		if (prettyPrintStatus) {
			headline = prpd.increaseLineHeaderLevel();
		}
		// begin attributes, id and id ref processing

		boolean haveSons = false;
		sb.append(">");
		sb.append(retline);

		// sons, follow processing

		if (getElements() != null) {

			java.util.List<fr.lip6.move.pnml.symmetricnet.finiteEnumerations.FEConstant> items = getElements();
			for (Iterator<FEConstant> iterator = items.iterator(); iterator
					.hasNext();) {
				FEConstant item = (FEConstant) iterator.next();

				sb.append(item.toPNML());

				haveSons = true;
			}

		}

		/** * */

		if (prettyPrintStatus) {
			headline = prpd.decreaseLineHeaderLevel();
		}

		if (haveSons) {
			sb.append(headline);
			sb.append("</cyclicenumeration>");
			sb.append(retline);
		} else {
			sb.delete(sb.lastIndexOf(">"), sb.length());
			sb.append("/>");
		}

		return sb.toString();
	}

	@SuppressWarnings("unchecked")
	public void fromPNML(OMElement locRoot, IdRefLinker idr)
			throws InnerBuildException, InvalidIDException,
			VoidRepositoryException {
		// 0
		// 0
		// 0
		// 1
		@SuppressWarnings("unused")
		CyclicEnumerationsFactory fact = new CyclicEnumerationsFactoryImpl();

		// processing id

		// processing idref

		// processing attributes

		// processing sons

		for (Iterator iterator = locRoot.getChildElements(); iterator.hasNext();) {
			@SuppressWarnings("unused")
			OMElement type = (OMElement) iterator.next();

			if (type.getLocalName().equals("feconstant")) {
				FEConstant item;
				item = new FiniteEnumerationsFactoryImpl().createFEConstant();
				item.fromPNML(type, idr);

				item.setSort(this);

				continue;
			}// end if

		}

	}

	/**
	 * -
	 */
	public boolean validateOCL(DiagnosticChain diagnostics) {

		TermsValidator val = new TermsValidator();
		boolean retour = true;

		if (getElements() != null) {
			java.util.List<fr.lip6.move.pnml.symmetricnet.finiteEnumerations.FEConstant> items = getElements();
			for (Iterator<FEConstant> iterator = items.iterator(); iterator
					.hasNext();) {
				FEConstant item = (FEConstant) iterator.next();
				retour &= item.validateOCL(diagnostics);
			}
		}

		retour &= val.validate(this, diagnostics, null);
		return retour;

	}

	public boolean equalSorts(Sort sort) {
		boolean isEqual = false;
		if (this.eClass().getName().equalsIgnoreCase(sort.eClass().getName())) {
			if (this.getContainerNamedSort() != null
					&& sort.getContainerNamedSort() != null) {
				isEqual = this.getContainerNamedSort().getName()
						.equalsIgnoreCase(
								sort.getContainerNamedSort().getName());
			} else {
				if ("CyclicEnumeration".equalsIgnoreCase(this.eClass()
						.getName())) {
					CyclicEnumeration myFE = (CyclicEnumeration) this;
					CyclicEnumeration thatFE = (CyclicEnumeration) sort;
					List<FEConstant> myConstants = myFE.getElements();
					List<FEConstant> thoseConstants = thatFE.getElements();
					int i = 0;
					int j = 0;

					for (; i < myConstants.size() && j < thoseConstants.size(); i++, j++) {
						if (myConstants.get(i).getName().equalsIgnoreCase(
								thoseConstants.get(j).getName())) {
							isEqual = true;
						} else {
							isEqual = false;
							break;
						}
					}
				}
			}
		}
		return isEqual;

	}
} // CyclicEnumerationImpl
