/**
 * (C) University Pierre & Marie Curie - UMR CNRS 7606 (LIP6/MoVe)
 * All rights reserved.   This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *  
 *  Contributors: 
 *    Lom HILLAH (LIP6) - Initial models and implementation
 *    Rachid Alahyane (UPMC) - Infrastructure and continuous integration
 *    Bastien Bouzerau (UPMC) - Architecture
 *    Guillaume Giffo (UPMC)  - Code generation refactoring, high-level API
 *
 * $Id ggiffo, Wed Sep 10 13:41:19 CEST 2008$
 */
package fr.lip6.move.pnml.symmetricnet.partitions.hlapi;

import java.util.ArrayList;
import java.util.List;

import org.apache.axiom.om.OMElement;
import org.eclipse.emf.common.util.DiagnosticChain;

import fr.lip6.move.pnml.framework.hlapi.HLAPIClass;
import fr.lip6.move.pnml.framework.utils.IdRefLinker;
import fr.lip6.move.pnml.framework.utils.ModelRepository;
import fr.lip6.move.pnml.framework.utils.exception.InnerBuildException;
import fr.lip6.move.pnml.framework.utils.exception.InvalidIDException;
import fr.lip6.move.pnml.framework.utils.exception.OtherException;
import fr.lip6.move.pnml.framework.utils.exception.VoidRepositoryException;
import fr.lip6.move.pnml.symmetricnet.partitions.Partition;
import fr.lip6.move.pnml.symmetricnet.partitions.PartitionElement;
import fr.lip6.move.pnml.symmetricnet.partitions.PartitionsFactory;
import fr.lip6.move.pnml.symmetricnet.partitions.impl.PartitionsFactoryImpl;
import fr.lip6.move.pnml.symmetricnet.terms.Declarations;
import fr.lip6.move.pnml.symmetricnet.terms.Sort;
import fr.lip6.move.pnml.symmetricnet.terms.hlapi.DeclarationsHLAPI;
import fr.lip6.move.pnml.symmetricnet.terms.hlapi.SortDeclHLAPI;
import fr.lip6.move.pnml.symmetricnet.terms.hlapi.SortHLAPI;
import fr.lip6.move.pnml.symmetricnet.terms.hlapi.TermsDeclarationHLAPI;

public class PartitionHLAPI implements HLAPIClass, TermsDeclarationHLAPI,
		SortDeclHLAPI {

	/**
	 * The contained LLAPI element.
	 */
	private Partition item;

	/**
	 * this constructor allows you to set all 'settable' values excepted
	 * container.
	 */

	public PartitionHLAPI(java.lang.String id

	, java.lang.String name

	, SortHLAPI def) throws InvalidIDException, VoidRepositoryException {// BEGIN
		// CONSTRUCTOR
		// BODY
		PartitionsFactory fact = new PartitionsFactoryImpl();
		item = fact.createPartition();

		if (id != null) {

			item.setId(ModelRepository.getInstance().getCurrentIdRepository()
					.checkId(id, this));
		}

		if (name != null) {

			item.setName(name);
		}

		if (def != null)
			item.setDef((Sort) def.getContainedItem());

	}

	/**
	 * this constructor allows you to set all 'settable' values, including
	 * container if any.
	 */

	public PartitionHLAPI(java.lang.String id

	, java.lang.String name

	, SortHLAPI def

	, DeclarationsHLAPI containerDeclarations) throws InvalidIDException,
			VoidRepositoryException {// BEGIN CONSTRUCTOR BODY
		PartitionsFactory fact = new PartitionsFactoryImpl();
		item = fact.createPartition();

		if (id != null) {

			item.setId(ModelRepository.getInstance().getCurrentIdRepository()
					.checkId(id, this));
		}

		if (name != null) {

			item.setName(name);
		}

		if (def != null)
			item.setDef((Sort) def.getContainedItem());

		if (containerDeclarations != null)
			item.setContainerDeclarations((Declarations) containerDeclarations
					.getContainedItem());

	}

	/**
	 * This constructor encapsulate a low level API object in HLAPI.
	 */
	public PartitionHLAPI(Partition lowLevelAPI) {
		item = lowLevelAPI;
	}

	// access to low level API
	/**
	 * Return encapsulated object
	 */
	public Partition getContainedItem() {
		return item;
	}

	// getters giving LLAPI object

	/**
	 * Return the encapsulate Low Level API object.
	 */
	public String getId() {
		return item.getId();
	}

	/**
	 * Return the encapsulate Low Level API object.
	 */
	public String getName() {
		return item.getName();
	}

	/**
	 * Return the encapsulate Low Level API object.
	 */
	public Declarations getContainerDeclarations() {
		return item.getContainerDeclarations();
	}

	/**
	 * Return the encapsulate Low Level API object.
	 */
	public Sort getDef() {
		return item.getDef();
	}

	/**
	 * Return the encapsulate Low Level API object.
	 */
	public List<PartitionElement> getPartitionelements() {
		return item.getPartitionelements();
	}

	// getters giving HLAPI object

	/**
	 * This accessor automatically encapsulate an element of the current object.
	 * WARNING : this creates a new object in memory.
	 * 
	 * @return : null if the element is null
	 */

	public DeclarationsHLAPI getContainerDeclarationsHLAPI() {
		if (item.getContainerDeclarations() == null)
			return null;
		return new DeclarationsHLAPI(item.getContainerDeclarations());
	}

	/**
	 * This accessor automatically encapsulate an element of the current object.
	 * WARNING : this creates a new object in memory.
	 * 
	 * @return : null if the element is null
	 */

	public SortHLAPI getDefHLAPI() {
		if (item.getDef() == null)
			return null;
		Sort object = item.getDef();

		if (object.getClass().equals(
				fr.lip6.move.pnml.symmetricnet.booleans.impl.BoolImpl.class)) {
			return new fr.lip6.move.pnml.symmetricnet.booleans.hlapi.BoolHLAPI(
					(fr.lip6.move.pnml.symmetricnet.booleans.Bool) object);
		}

		if (object
				.getClass()
				.equals(
						fr.lip6.move.pnml.symmetricnet.cyclicEnumerations.impl.CyclicEnumerationImpl.class)) {
			return new fr.lip6.move.pnml.symmetricnet.cyclicEnumerations.hlapi.CyclicEnumerationHLAPI(
					(fr.lip6.move.pnml.symmetricnet.cyclicEnumerations.CyclicEnumeration) object);
		}

		if (object.getClass().equals(
				fr.lip6.move.pnml.symmetricnet.dots.impl.DotImpl.class)) {
			return new fr.lip6.move.pnml.symmetricnet.dots.hlapi.DotHLAPI(
					(fr.lip6.move.pnml.symmetricnet.dots.Dot) object);
		}

		if (object
				.getClass()
				.equals(
						fr.lip6.move.pnml.symmetricnet.finiteEnumerations.impl.FiniteEnumerationImpl.class)) {
			return new fr.lip6.move.pnml.symmetricnet.finiteEnumerations.hlapi.FiniteEnumerationHLAPI(
					(fr.lip6.move.pnml.symmetricnet.finiteEnumerations.FiniteEnumeration) object);
		}

		if (object
				.getClass()
				.equals(
						fr.lip6.move.pnml.symmetricnet.finiteIntRanges.impl.FiniteIntRangeImpl.class)) {
			return new fr.lip6.move.pnml.symmetricnet.finiteIntRanges.hlapi.FiniteIntRangeHLAPI(
					(fr.lip6.move.pnml.symmetricnet.finiteIntRanges.FiniteIntRange) object);
		}

		if (object.getClass().equals(
				fr.lip6.move.pnml.symmetricnet.integers.impl.NaturalImpl.class)) {
			return new fr.lip6.move.pnml.symmetricnet.integers.hlapi.NaturalHLAPI(
					(fr.lip6.move.pnml.symmetricnet.integers.Natural) object);
		}

		if (object
				.getClass()
				.equals(
						fr.lip6.move.pnml.symmetricnet.integers.impl.PositiveImpl.class)) {
			return new fr.lip6.move.pnml.symmetricnet.integers.hlapi.PositiveHLAPI(
					(fr.lip6.move.pnml.symmetricnet.integers.Positive) object);
		}

		if (object
				.getClass()
				.equals(
						fr.lip6.move.pnml.symmetricnet.integers.impl.HLIntegerImpl.class)) {
			return new fr.lip6.move.pnml.symmetricnet.integers.hlapi.HLIntegerHLAPI(
					(fr.lip6.move.pnml.symmetricnet.integers.HLInteger) object);
		}

		if (object
				.getClass()
				.equals(
						fr.lip6.move.pnml.symmetricnet.terms.impl.MultisetSortImpl.class)) {
			return new fr.lip6.move.pnml.symmetricnet.terms.hlapi.MultisetSortHLAPI(
					(fr.lip6.move.pnml.symmetricnet.terms.MultisetSort) object);
		}

		if (object
				.getClass()
				.equals(
						fr.lip6.move.pnml.symmetricnet.terms.impl.ProductSortImpl.class)) {
			return new fr.lip6.move.pnml.symmetricnet.terms.hlapi.ProductSortHLAPI(
					(fr.lip6.move.pnml.symmetricnet.terms.ProductSort) object);
		}

		if (object.getClass().equals(
				fr.lip6.move.pnml.symmetricnet.terms.impl.UserSortImpl.class)) {
			return new fr.lip6.move.pnml.symmetricnet.terms.hlapi.UserSortHLAPI(
					(fr.lip6.move.pnml.symmetricnet.terms.UserSort) object);
		}

		return null;
	}

	/**
	 * This accessor automatically encapsulate all elements of the selected
	 * sublist. WARNING : this can creates a lot of new object in memory.
	 */

	public List<PartitionElementHLAPI> getPartitionelementsHLAPI() {
		List<PartitionElementHLAPI> retour = new ArrayList<PartitionElementHLAPI>();
		for (PartitionElement elemnt : getPartitionelements()) {
			retour.add(new PartitionElementHLAPI(elemnt));
		}
		return retour;
	}

	// Special getter for list of generics object, return only one object type.

	// setters (including container setter if aviable)

	/**
	 * set Id
	 */
	public void setIdHLAPI(

	java.lang.String elem) throws InvalidIDException, VoidRepositoryException {

		if (elem != null) {

			try {
				item.setId(ModelRepository.getInstance()
						.getCurrentIdRepository().changeId(this, elem));
			} catch (OtherException e) {
				ModelRepository.getInstance().getCurrentIdRepository().checkId(
						elem, this);
			}
		}

	}

	/**
	 * set Name
	 */
	public void setNameHLAPI(

	java.lang.String elem) {

		if (elem != null) {

			item.setName(elem);
		}

	}

	/**
	 * set Def
	 */
	public void setDefHLAPI(

	SortHLAPI elem) {

		if (elem != null)
			item.setDef((Sort) elem.getContainedItem());

	}

	/**
	 * set ContainerDeclarations
	 */
	public void setContainerDeclarationsHLAPI(

	DeclarationsHLAPI elem) {

		if (elem != null)
			item.setContainerDeclarations((Declarations) elem
					.getContainedItem());

	}

	// setters/remover for lists.

	public void addPartitionelementsHLAPI(PartitionElementHLAPI unit) {
		item.getPartitionelements().add(
				(PartitionElement) unit.getContainedItem());
	}

	public void removePartitionelementsHLAPI(PartitionElementHLAPI unit) {
		item.getPartitionelements().remove(
				(PartitionElement) unit.getContainedItem());
	}

	// equals method
	public boolean equals(PartitionHLAPI item) {
		return item.getContainedItem().equals(getContainedItem());
	}

	// PNML

	/**
	 * return the PNML xml tree for this object.
	 */
	public String toPNML() {
		return item.toPNML();
	}

	/**
	 * creates an object from the xml nodes.(symetric work of toPNML)
	 */
	public void fromPNML(OMElement subRoot, IdRefLinker idr)
			throws InnerBuildException, InvalidIDException,
			VoidRepositoryException {
		item.fromPNML(subRoot, idr);
	}

	public boolean validateOCL(DiagnosticChain diagnostics) {
		return item.validateOCL(diagnostics);
	}

}