/**
 * (C) University Pierre & Marie Curie - UMR CNRS 7606 (LIP6/MoVe)
 * All rights reserved.   This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *  
 *  Contributors: 
 *    Lom HILLAH (LIP6) - Initial models and implementation
 *    Rachid Alahyane (UPMC) - Infrastructure and continuous integration
 *    Bastien Bouzerau (UPMC) - Architecture
 *    Guillaume Giffo (UPMC)  - Code generation refactoring, high-level API
 *
 * $Id$
 */
package fr.lip6.move.pnml.symmetricnet.terms.impl;

import java.util.Iterator;

import javax.xml.namespace.QName;

import org.apache.axiom.om.OMElement;
import org.eclipse.emf.common.notify.Notification;
import org.eclipse.emf.common.notify.NotificationChain;
import org.eclipse.emf.common.util.DiagnosticChain;
import org.eclipse.emf.ecore.EClass;
import org.eclipse.emf.ecore.InternalEObject;
import org.eclipse.emf.ecore.impl.ENotificationImpl;

import fr.lip6.move.pnml.framework.utils.IdRefLinker;
import fr.lip6.move.pnml.framework.utils.ModelRepository;
import fr.lip6.move.pnml.framework.utils.PrettyPrintData;
import fr.lip6.move.pnml.framework.utils.exception.InnerBuildException;
import fr.lip6.move.pnml.framework.utils.exception.InvalidIDException;
import fr.lip6.move.pnml.framework.utils.exception.VoidRepositoryException;
import fr.lip6.move.pnml.symmetricnet.booleans.Bool;
import fr.lip6.move.pnml.symmetricnet.booleans.impl.BooleansFactoryImpl;
import fr.lip6.move.pnml.symmetricnet.cyclicEnumerations.CyclicEnumeration;
import fr.lip6.move.pnml.symmetricnet.cyclicEnumerations.impl.CyclicEnumerationsFactoryImpl;
import fr.lip6.move.pnml.symmetricnet.dots.Dot;
import fr.lip6.move.pnml.symmetricnet.dots.impl.DotsFactoryImpl;
import fr.lip6.move.pnml.symmetricnet.finiteEnumerations.FiniteEnumeration;
import fr.lip6.move.pnml.symmetricnet.finiteEnumerations.impl.FiniteEnumerationsFactoryImpl;
import fr.lip6.move.pnml.symmetricnet.finiteIntRanges.FiniteIntRange;
import fr.lip6.move.pnml.symmetricnet.finiteIntRanges.impl.FiniteIntRangesFactoryImpl;
import fr.lip6.move.pnml.symmetricnet.integers.HLInteger;
import fr.lip6.move.pnml.symmetricnet.integers.Natural;
import fr.lip6.move.pnml.symmetricnet.integers.Positive;
import fr.lip6.move.pnml.symmetricnet.integers.impl.IntegersFactoryImpl;
import fr.lip6.move.pnml.symmetricnet.terms.MultisetSort;
import fr.lip6.move.pnml.symmetricnet.terms.NamedSort;
import fr.lip6.move.pnml.symmetricnet.terms.ProductSort;
import fr.lip6.move.pnml.symmetricnet.terms.Sort;
import fr.lip6.move.pnml.symmetricnet.terms.TermsFactory;
import fr.lip6.move.pnml.symmetricnet.terms.TermsPackage;
import fr.lip6.move.pnml.symmetricnet.terms.UserSort;
import fr.lip6.move.pnml.symmetricnet.terms.util.TermsValidator;

/**
 * <!-- begin-user-doc --> An implementation of the model object '
 * <em><b>Named Sort</b></em>'. <!-- end-user-doc -->
 * <p>
 * The following features are implemented:
 * <ul>
 * <li>
 * {@link fr.lip6.move.pnml.symmetricnet.terms.impl.NamedSortImpl#getSortdef
 * <em>Sortdef</em>}</li>
 * </ul>
 * </p>
 * 
 * @generated
 */
public class NamedSortImpl extends SortDeclImpl implements NamedSort {
	/**
	 * The cached value of the '{@link #getSortdef() <em>Sortdef</em>}'
	 * containment reference. <!-- begin-user-doc --> <!-- end-user-doc -->
	 * 
	 * @see #getSortdef()
	 * @generated
	 * @ordered
	 */
	protected Sort sortdef;

	/**
	 * <!-- begin-user-doc --> <!-- end-user-doc -->
	 * 
	 * @generated
	 */
	protected NamedSortImpl() {
		super();
	}

	/**
	 * <!-- begin-user-doc --> <!-- end-user-doc -->
	 * 
	 * @generated
	 */
	@Override
	protected EClass eStaticClass() {
		return TermsPackage.Literals.NAMED_SORT;
	}

	/**
	 * <!-- begin-user-doc --> <!-- end-user-doc -->
	 * 
	 * @generated
	 */
	public Sort getSortdef() {
		return sortdef;
	}

	/**
	 * <!-- begin-user-doc --> <!-- end-user-doc -->
	 * 
	 * @generated
	 */
	public NotificationChain basicSetSortdef(Sort newSortdef,
			NotificationChain msgs) {
		Sort oldSortdef = sortdef;
		sortdef = newSortdef;
		if (eNotificationRequired()) {
			ENotificationImpl notification = new ENotificationImpl(this,
					Notification.SET, TermsPackage.NAMED_SORT__SORTDEF,
					oldSortdef, newSortdef);
			if (msgs == null)
				msgs = notification;
			else
				msgs.add(notification);
		}
		return msgs;
	}

	/**
	 * <!-- begin-user-doc --> <!-- end-user-doc -->
	 * 
	 * @generated
	 */
	public void setSortdef(Sort newSortdef) {
		if (newSortdef != sortdef) {
			NotificationChain msgs = null;
			if (sortdef != null)
				msgs = ((InternalEObject) sortdef).eInverseRemove(this,
						TermsPackage.SORT__CONTAINER_NAMED_SORT, Sort.class,
						msgs);
			if (newSortdef != null)
				msgs = ((InternalEObject) newSortdef).eInverseAdd(this,
						TermsPackage.SORT__CONTAINER_NAMED_SORT, Sort.class,
						msgs);
			msgs = basicSetSortdef(newSortdef, msgs);
			if (msgs != null)
				msgs.dispatch();
		} else if (eNotificationRequired())
			eNotify(new ENotificationImpl(this, Notification.SET,
					TermsPackage.NAMED_SORT__SORTDEF, newSortdef, newSortdef));
	}

	/**
	 * <!-- begin-user-doc --> <!-- end-user-doc -->
	 * 
	 * @generated
	 */
	@Override
	public NotificationChain eInverseAdd(InternalEObject otherEnd,
			int featureID, NotificationChain msgs) {
		switch (featureID) {
		case TermsPackage.NAMED_SORT__SORTDEF:
			if (sortdef != null)
				msgs = ((InternalEObject) sortdef).eInverseRemove(this,
						EOPPOSITE_FEATURE_BASE
								- TermsPackage.NAMED_SORT__SORTDEF, null, msgs);
			return basicSetSortdef((Sort) otherEnd, msgs);
		}
		return super.eInverseAdd(otherEnd, featureID, msgs);
	}

	/**
	 * <!-- begin-user-doc --> <!-- end-user-doc -->
	 * 
	 * @generated
	 */
	@Override
	public NotificationChain eInverseRemove(InternalEObject otherEnd,
			int featureID, NotificationChain msgs) {
		switch (featureID) {
		case TermsPackage.NAMED_SORT__SORTDEF:
			return basicSetSortdef(null, msgs);
		}
		return super.eInverseRemove(otherEnd, featureID, msgs);
	}

	/**
	 * <!-- begin-user-doc --> <!-- end-user-doc -->
	 * 
	 * @generated
	 */
	@Override
	public Object eGet(int featureID, boolean resolve, boolean coreType) {
		switch (featureID) {
		case TermsPackage.NAMED_SORT__SORTDEF:
			return getSortdef();
		}
		return super.eGet(featureID, resolve, coreType);
	}

	/**
	 * <!-- begin-user-doc --> <!-- end-user-doc -->
	 * 
	 * @generated
	 */
	@Override
	public void eSet(int featureID, Object newValue) {
		switch (featureID) {
		case TermsPackage.NAMED_SORT__SORTDEF:
			setSortdef((Sort) newValue);
			return;
		}
		super.eSet(featureID, newValue);
	}

	/**
	 * <!-- begin-user-doc --> <!-- end-user-doc -->
	 * 
	 * @generated
	 */
	@Override
	public void eUnset(int featureID) {
		switch (featureID) {
		case TermsPackage.NAMED_SORT__SORTDEF:
			setSortdef((Sort) null);
			return;
		}
		super.eUnset(featureID);
	}

	/**
	 * <!-- begin-user-doc --> <!-- end-user-doc -->
	 * 
	 * @generated
	 */
	@Override
	public boolean eIsSet(int featureID) {
		switch (featureID) {
		case TermsPackage.NAMED_SORT__SORTDEF:
			return sortdef != null;
		}
		return super.eIsSet(featureID);
	}

	/**
	 * Return the string containing the pnml output
	 */
	public String toPNML() {
		// id 1
		// idref 0
		// attributes 1
		// sons 1

		Boolean prettyPrintStatus = ModelRepository.getInstance()
				.isPrettyPrintActive();
		String retline = "";
		String headline = "";
		PrettyPrintData prpd = null;
		if (prettyPrintStatus) {
			retline = "\n";
			prpd = ModelRepository.getInstance().getPrettyPrintData();
			headline = prpd.getCurrentLineHeader();
		}

		StringBuffer sb = new StringBuffer();
		sb.append(headline);
		sb.append("<namedsort");
		if (prettyPrintStatus) {
			headline = prpd.increaseLineHeaderLevel();
		}
		// begin attributes, id and id ref processing

		if (getId() != null) {
			sb.append(" id");
			sb.append("=\"");
			sb.append(getId());
			sb.append("\"");
		}

		if (getName() != null) {
			sb.append(" name");
			sb.append("=\"");
			sb.append(getName());
			sb.append("\"");
		}

		boolean haveSons = false;
		sb.append(">");
		sb.append(retline);

		// sons, follow processing

		if (getSortdef() != null) {

			String top = getSortdef().toPNML();
			if (!top.equals("")) {

				sb.append(top);

				haveSons = true;
			}

		}

		/** * */

		if (prettyPrintStatus) {
			headline = prpd.decreaseLineHeaderLevel();
		}

		if (haveSons) {
			sb.append(headline);
			sb.append("</namedsort>");
			sb.append(retline);
		} else {
			sb.delete(sb.lastIndexOf(">"), sb.length());
			sb.append("/>");
		}

		return sb.toString();
	}

	@SuppressWarnings("unchecked")
	public void fromPNML(OMElement locRoot, IdRefLinker idr)
			throws InnerBuildException, InvalidIDException,
			VoidRepositoryException {
		// 1
		// 0
		// 1
		// 1
		@SuppressWarnings("unused")
		TermsFactory fact = new TermsFactoryImpl();

		// processing id

		if (locRoot.getAttributeValue(new QName("id")) != null) {
			this.setId(new java.lang.String(locRoot
					.getAttributeValue(new QName("id"))));
			ModelRepository.getInstance().getCurrentIdRepository().checkId(
					new java.lang.String(locRoot.getAttributeValue(new QName(
							"id"))).toString(), (Object) this);
		}

		// processing idref

		// processing attributes

		if (locRoot.getAttributeValue(new QName("name")) != null) {
			try {
				this.setName(new String(locRoot.getAttributeValue(new QName(
						"name"))));
			} catch (Exception e) {
				throw new fr.lip6.move.pnml.framework.utils.exception.InnerBuildException(
						e);
			}
		}

		// processing sons

		for (Iterator iterator = locRoot.getChildElements(); iterator.hasNext();) {
			@SuppressWarnings("unused")
			OMElement type = (OMElement) iterator.next();

			if (type.getLocalName().equals("multisetsort")) {
				MultisetSort item;
				item = new TermsFactoryImpl().createMultisetSort();
				item.fromPNML(type, idr);

				item.setContainerNamedSort(this);

				continue;
			}// end if

			if (type.getLocalName().equals("productsort")) {
				ProductSort item;
				item = new TermsFactoryImpl().createProductSort();
				item.fromPNML(type, idr);

				item.setContainerNamedSort(this);

				continue;
			}// end if

			if (type.getLocalName().equals("usersort")) {
				UserSort item;
				item = new TermsFactoryImpl().createUserSort();
				item.fromPNML(type, idr);

				item.setContainerNamedSort(this);

				continue;
			}// end if

			if (type.getLocalName().equals("null")) {
				Bool item;
				item = new BooleansFactoryImpl().createBool();
				item.fromPNML(type, idr);

				item.setContainerNamedSort(this);

				continue;
			}// end if

			if (type.getLocalName().equals("cyclicenumeration")) {
				CyclicEnumeration item;
				item = new CyclicEnumerationsFactoryImpl()
						.createCyclicEnumeration();
				item.fromPNML(type, idr);

				item.setContainerNamedSort(this);

				continue;
			}// end if

			if (type.getLocalName().equals("dot")) {
				Dot item;
				item = new DotsFactoryImpl().createDot();
				item.fromPNML(type, idr);

				item.setContainerNamedSort(this);

				continue;
			}// end if

			if (type.getLocalName().equals("finiteenumeration")) {
				FiniteEnumeration item;
				item = new FiniteEnumerationsFactoryImpl()
						.createFiniteEnumeration();
				item.fromPNML(type, idr);

				item.setContainerNamedSort(this);

				continue;
			}// end if

			if (type.getLocalName().equals("finiteintrange")) {
				FiniteIntRange item;
				item = new FiniteIntRangesFactoryImpl().createFiniteIntRange();
				item.fromPNML(type, idr);

				item.setContainerNamedSort(this);

				continue;
			}// end if

			if (type.getLocalName().equals("natural")) {
				Natural item;
				item = new IntegersFactoryImpl().createNatural();
				item.fromPNML(type, idr);

				item.setContainerNamedSort(this);

				continue;
			}// end if

			if (type.getLocalName().equals("positive")) {
				Positive item;
				item = new IntegersFactoryImpl().createPositive();
				item.fromPNML(type, idr);

				item.setContainerNamedSort(this);

				continue;
			}// end if

			if (type.getLocalName().equals("integer")) {
				HLInteger item;
				item = new IntegersFactoryImpl().createHLInteger();
				item.fromPNML(type, idr);

				item.setContainerNamedSort(this);

				continue;
			}// end if

		}

	}

	/**
	 * -
	 */
	public boolean validateOCL(DiagnosticChain diagnostics) {

		TermsValidator val = new TermsValidator();
		boolean retour = true;

		if (getSortdef() != null) {
			retour &= getSortdef().validateOCL(diagnostics);
		}

		retour &= val.validate(this, diagnostics, null);
		return retour;

	}
} // NamedSortImpl
