/**
 * (C) University Pierre & Marie Curie - UMR CNRS 7606 (LIP6/MoVe)
 * All rights reserved.   This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *  
 *  Contributors: 
 *    Lom HILLAH (LIP6) - Initial models and implementation
 *    Rachid Alahyane (UPMC) - Infrastructure and continuous integration
 *    Bastien Bouzerau (UPMC) - Architecture
 *    Guillaume Giffo (UPMC)  - Code generation refactoring, high-level API
 *
 * $Id$
 */
package fr.lip6.move.pnml.symmetricnet.terms.impl;

import java.util.Iterator;

import javax.xml.namespace.QName;

import org.apache.axiom.om.OMElement;
import org.eclipse.emf.common.notify.Notification;
import org.eclipse.emf.common.notify.NotificationChain;
import org.eclipse.emf.common.util.DiagnosticChain;
import org.eclipse.emf.ecore.EClass;
import org.eclipse.emf.ecore.InternalEObject;
import org.eclipse.emf.ecore.impl.ENotificationImpl;
import org.eclipse.emf.ecore.util.EcoreUtil;

import fr.lip6.move.pnml.framework.utils.IdRefLinker;
import fr.lip6.move.pnml.framework.utils.ModelRepository;
import fr.lip6.move.pnml.framework.utils.PrettyPrintData;
import fr.lip6.move.pnml.framework.utils.exception.InnerBuildException;
import fr.lip6.move.pnml.framework.utils.exception.InvalidIDException;
import fr.lip6.move.pnml.framework.utils.exception.VoidRepositoryException;
import fr.lip6.move.pnml.symmetricnet.booleans.Bool;
import fr.lip6.move.pnml.symmetricnet.booleans.impl.BooleansFactoryImpl;
import fr.lip6.move.pnml.symmetricnet.cyclicEnumerations.CyclicEnumeration;
import fr.lip6.move.pnml.symmetricnet.cyclicEnumerations.impl.CyclicEnumerationsFactoryImpl;
import fr.lip6.move.pnml.symmetricnet.dots.Dot;
import fr.lip6.move.pnml.symmetricnet.dots.impl.DotsFactoryImpl;
import fr.lip6.move.pnml.symmetricnet.finiteEnumerations.FiniteEnumeration;
import fr.lip6.move.pnml.symmetricnet.finiteEnumerations.impl.FiniteEnumerationsFactoryImpl;
import fr.lip6.move.pnml.symmetricnet.finiteIntRanges.FiniteIntRange;
import fr.lip6.move.pnml.symmetricnet.finiteIntRanges.impl.FiniteIntRangesFactoryImpl;
import fr.lip6.move.pnml.symmetricnet.integers.HLInteger;
import fr.lip6.move.pnml.symmetricnet.integers.Natural;
import fr.lip6.move.pnml.symmetricnet.integers.Positive;
import fr.lip6.move.pnml.symmetricnet.integers.impl.IntegersFactoryImpl;
import fr.lip6.move.pnml.symmetricnet.terms.MultisetSort;
import fr.lip6.move.pnml.symmetricnet.terms.NamedOperator;
import fr.lip6.move.pnml.symmetricnet.terms.ProductSort;
import fr.lip6.move.pnml.symmetricnet.terms.Sort;
import fr.lip6.move.pnml.symmetricnet.terms.TermsFactory;
import fr.lip6.move.pnml.symmetricnet.terms.TermsPackage;
import fr.lip6.move.pnml.symmetricnet.terms.UserSort;
import fr.lip6.move.pnml.symmetricnet.terms.VariableDecl;
import fr.lip6.move.pnml.symmetricnet.terms.util.TermsValidator;

/**
 * <!-- begin-user-doc --> An implementation of the model object '
 * <em><b>Variable Decl</b></em>'. <!-- end-user-doc -->
 * <p>
 * The following features are implemented:
 * <ul>
 * <li>
 * {@link fr.lip6.move.pnml.symmetricnet.terms.impl.VariableDeclImpl#getSort
 * <em>Sort</em>}</li>
 * <li>
 * {@link fr.lip6.move.pnml.symmetricnet.terms.impl.VariableDeclImpl#getContainerNamedOperator
 * <em>Container Named Operator</em>}</li>
 * </ul>
 * </p>
 * 
 * @generated
 */
public class VariableDeclImpl extends TermsDeclarationImpl implements
		VariableDecl {
	/**
	 * The cached value of the '{@link #getSort() <em>Sort</em>}' containment
	 * reference. <!-- begin-user-doc --> <!-- end-user-doc -->
	 * 
	 * @see #getSort()
	 * @generated
	 * @ordered
	 */
	protected Sort sort;

	/**
	 * <!-- begin-user-doc --> <!-- end-user-doc -->
	 * 
	 * @generated
	 */
	protected VariableDeclImpl() {
		super();
	}

	/**
	 * <!-- begin-user-doc --> <!-- end-user-doc -->
	 * 
	 * @generated
	 */
	@Override
	protected EClass eStaticClass() {
		return TermsPackage.Literals.VARIABLE_DECL;
	}

	/**
	 * <!-- begin-user-doc --> <!-- end-user-doc -->
	 * 
	 * @generated
	 */
	public Sort getSort() {
		return sort;
	}

	/**
	 * <!-- begin-user-doc --> <!-- end-user-doc -->
	 * 
	 * @generated
	 */
	public NotificationChain basicSetSort(Sort newSort, NotificationChain msgs) {
		Sort oldSort = sort;
		sort = newSort;
		if (eNotificationRequired()) {
			ENotificationImpl notification = new ENotificationImpl(this,
					Notification.SET, TermsPackage.VARIABLE_DECL__SORT,
					oldSort, newSort);
			if (msgs == null)
				msgs = notification;
			else
				msgs.add(notification);
		}
		return msgs;
	}

	/**
	 * <!-- begin-user-doc --> <!-- end-user-doc -->
	 * 
	 * @generated
	 */
	public void setSort(Sort newSort) {
		if (newSort != sort) {
			NotificationChain msgs = null;
			if (sort != null)
				msgs = ((InternalEObject) sort).eInverseRemove(this,
						TermsPackage.SORT__CONTAINER_VARIABLE_DECL, Sort.class,
						msgs);
			if (newSort != null)
				msgs = ((InternalEObject) newSort).eInverseAdd(this,
						TermsPackage.SORT__CONTAINER_VARIABLE_DECL, Sort.class,
						msgs);
			msgs = basicSetSort(newSort, msgs);
			if (msgs != null)
				msgs.dispatch();
		} else if (eNotificationRequired())
			eNotify(new ENotificationImpl(this, Notification.SET,
					TermsPackage.VARIABLE_DECL__SORT, newSort, newSort));
	}

	/**
	 * <!-- begin-user-doc --> <!-- end-user-doc -->
	 * 
	 * @generated
	 */
	public NamedOperator getContainerNamedOperator() {
		if (eContainerFeatureID != TermsPackage.VARIABLE_DECL__CONTAINER_NAMED_OPERATOR)
			return null;
		return (NamedOperator) eContainer();
	}

	/**
	 * <!-- begin-user-doc --> <!-- end-user-doc -->
	 * 
	 * @generated
	 */
	public NotificationChain basicSetContainerNamedOperator(
			NamedOperator newContainerNamedOperator, NotificationChain msgs) {
		msgs = eBasicSetContainer((InternalEObject) newContainerNamedOperator,
				TermsPackage.VARIABLE_DECL__CONTAINER_NAMED_OPERATOR, msgs);
		return msgs;
	}

	/**
	 * <!-- begin-user-doc --> <!-- end-user-doc -->
	 * 
	 * @generated
	 */
	public void setContainerNamedOperator(
			NamedOperator newContainerNamedOperator) {
		if (newContainerNamedOperator != eInternalContainer()
				|| (eContainerFeatureID != TermsPackage.VARIABLE_DECL__CONTAINER_NAMED_OPERATOR && newContainerNamedOperator != null)) {
			if (EcoreUtil.isAncestor(this, newContainerNamedOperator))
				throw new IllegalArgumentException(
						"Recursive containment not allowed for " + toString());
			NotificationChain msgs = null;
			if (eInternalContainer() != null)
				msgs = eBasicRemoveFromContainer(msgs);
			if (newContainerNamedOperator != null)
				msgs = ((InternalEObject) newContainerNamedOperator)
						.eInverseAdd(this,
								TermsPackage.NAMED_OPERATOR__PARAMETERS,
								NamedOperator.class, msgs);
			msgs = basicSetContainerNamedOperator(newContainerNamedOperator,
					msgs);
			if (msgs != null)
				msgs.dispatch();
		} else if (eNotificationRequired())
			eNotify(new ENotificationImpl(this, Notification.SET,
					TermsPackage.VARIABLE_DECL__CONTAINER_NAMED_OPERATOR,
					newContainerNamedOperator, newContainerNamedOperator));
	}

	/**
	 * <!-- begin-user-doc --> <!-- end-user-doc -->
	 * 
	 * @generated
	 */
	@Override
	public NotificationChain eInverseAdd(InternalEObject otherEnd,
			int featureID, NotificationChain msgs) {
		switch (featureID) {
		case TermsPackage.VARIABLE_DECL__SORT:
			if (sort != null)
				msgs = ((InternalEObject) sort).eInverseRemove(this,
						EOPPOSITE_FEATURE_BASE
								- TermsPackage.VARIABLE_DECL__SORT, null, msgs);
			return basicSetSort((Sort) otherEnd, msgs);
		case TermsPackage.VARIABLE_DECL__CONTAINER_NAMED_OPERATOR:
			if (eInternalContainer() != null)
				msgs = eBasicRemoveFromContainer(msgs);
			return basicSetContainerNamedOperator((NamedOperator) otherEnd,
					msgs);
		}
		return super.eInverseAdd(otherEnd, featureID, msgs);
	}

	/**
	 * <!-- begin-user-doc --> <!-- end-user-doc -->
	 * 
	 * @generated
	 */
	@Override
	public NotificationChain eInverseRemove(InternalEObject otherEnd,
			int featureID, NotificationChain msgs) {
		switch (featureID) {
		case TermsPackage.VARIABLE_DECL__SORT:
			return basicSetSort(null, msgs);
		case TermsPackage.VARIABLE_DECL__CONTAINER_NAMED_OPERATOR:
			return basicSetContainerNamedOperator(null, msgs);
		}
		return super.eInverseRemove(otherEnd, featureID, msgs);
	}

	/**
	 * <!-- begin-user-doc --> <!-- end-user-doc -->
	 * 
	 * @generated
	 */
	@Override
	public NotificationChain eBasicRemoveFromContainerFeature(
			NotificationChain msgs) {
		switch (eContainerFeatureID) {
		case TermsPackage.VARIABLE_DECL__CONTAINER_NAMED_OPERATOR:
			return eInternalContainer().eInverseRemove(this,
					TermsPackage.NAMED_OPERATOR__PARAMETERS,
					NamedOperator.class, msgs);
		}
		return super.eBasicRemoveFromContainerFeature(msgs);
	}

	/**
	 * <!-- begin-user-doc --> <!-- end-user-doc -->
	 * 
	 * @generated
	 */
	@Override
	public Object eGet(int featureID, boolean resolve, boolean coreType) {
		switch (featureID) {
		case TermsPackage.VARIABLE_DECL__SORT:
			return getSort();
		case TermsPackage.VARIABLE_DECL__CONTAINER_NAMED_OPERATOR:
			return getContainerNamedOperator();
		}
		return super.eGet(featureID, resolve, coreType);
	}

	/**
	 * <!-- begin-user-doc --> <!-- end-user-doc -->
	 * 
	 * @generated
	 */
	@Override
	public void eSet(int featureID, Object newValue) {
		switch (featureID) {
		case TermsPackage.VARIABLE_DECL__SORT:
			setSort((Sort) newValue);
			return;
		case TermsPackage.VARIABLE_DECL__CONTAINER_NAMED_OPERATOR:
			setContainerNamedOperator((NamedOperator) newValue);
			return;
		}
		super.eSet(featureID, newValue);
	}

	/**
	 * <!-- begin-user-doc --> <!-- end-user-doc -->
	 * 
	 * @generated
	 */
	@Override
	public void eUnset(int featureID) {
		switch (featureID) {
		case TermsPackage.VARIABLE_DECL__SORT:
			setSort((Sort) null);
			return;
		case TermsPackage.VARIABLE_DECL__CONTAINER_NAMED_OPERATOR:
			setContainerNamedOperator((NamedOperator) null);
			return;
		}
		super.eUnset(featureID);
	}

	/**
	 * <!-- begin-user-doc --> <!-- end-user-doc -->
	 * 
	 * @generated
	 */
	@Override
	public boolean eIsSet(int featureID) {
		switch (featureID) {
		case TermsPackage.VARIABLE_DECL__SORT:
			return sort != null;
		case TermsPackage.VARIABLE_DECL__CONTAINER_NAMED_OPERATOR:
			return getContainerNamedOperator() != null;
		}
		return super.eIsSet(featureID);
	}

	/**
	 * Return the string containing the pnml output
	 */
	public String toPNML() {
		// id 1
		// idref 0
		// attributes 1
		// sons 1

		Boolean prettyPrintStatus = ModelRepository.getInstance()
				.isPrettyPrintActive();
		String retline = "";
		String headline = "";
		PrettyPrintData prpd = null;
		if (prettyPrintStatus) {
			retline = "\n";
			prpd = ModelRepository.getInstance().getPrettyPrintData();
			headline = prpd.getCurrentLineHeader();
		}

		StringBuffer sb = new StringBuffer();
		sb.append(headline);
		sb.append("<variabledecl");
		if (prettyPrintStatus) {
			headline = prpd.increaseLineHeaderLevel();
		}
		// begin attributes, id and id ref processing

		if (getId() != null) {
			sb.append(" id");
			sb.append("=\"");
			sb.append(getId());
			sb.append("\"");
		}

		if (getName() != null) {
			sb.append(" name");
			sb.append("=\"");
			sb.append(getName());
			sb.append("\"");
		}

		boolean haveSons = false;
		sb.append(">");
		sb.append(retline);

		// sons, follow processing

		if (getSort() != null) {

			String top = getSort().toPNML();
			if (!top.equals("")) {

				sb.append(top);

				haveSons = true;
			}

		}

		/** * */

		if (prettyPrintStatus) {
			headline = prpd.decreaseLineHeaderLevel();
		}

		if (haveSons) {
			sb.append(headline);
			sb.append("</variabledecl>");
			sb.append(retline);
		} else {
			sb.delete(sb.lastIndexOf(">"), sb.length());
			sb.append("/>");
		}

		return sb.toString();
	}

	@SuppressWarnings("unchecked")
	public void fromPNML(OMElement locRoot, IdRefLinker idr)
			throws InnerBuildException, InvalidIDException,
			VoidRepositoryException {
		// 1
		// 0
		// 1
		// 1
		@SuppressWarnings("unused")
		TermsFactory fact = new TermsFactoryImpl();

		// processing id

		if (locRoot.getAttributeValue(new QName("id")) != null) {
			this.setId(new java.lang.String(locRoot
					.getAttributeValue(new QName("id"))));
			ModelRepository.getInstance().getCurrentIdRepository().checkId(
					new java.lang.String(locRoot.getAttributeValue(new QName(
							"id"))).toString(), (Object) this);
		}

		// processing idref

		// processing attributes

		if (locRoot.getAttributeValue(new QName("name")) != null) {
			try {
				this.setName(new String(locRoot.getAttributeValue(new QName(
						"name"))));
			} catch (Exception e) {
				throw new fr.lip6.move.pnml.framework.utils.exception.InnerBuildException(
						e);
			}
		}

		// processing sons

		for (Iterator iterator = locRoot.getChildElements(); iterator.hasNext();) {
			@SuppressWarnings("unused")
			OMElement type = (OMElement) iterator.next();

			if (type.getLocalName().equals("multisetsort")) {
				MultisetSort item;
				item = new TermsFactoryImpl().createMultisetSort();
				item.fromPNML(type, idr);

				item.setContainerVariableDecl(this);

				continue;
			}// end if

			if (type.getLocalName().equals("productsort")) {
				ProductSort item;
				item = new TermsFactoryImpl().createProductSort();
				item.fromPNML(type, idr);

				item.setContainerVariableDecl(this);

				continue;
			}// end if

			if (type.getLocalName().equals("usersort")) {
				UserSort item;
				item = new TermsFactoryImpl().createUserSort();
				item.fromPNML(type, idr);

				item.setContainerVariableDecl(this);

				continue;
			}// end if

			if (type.getLocalName().equals("null")) {
				Bool item;
				item = new BooleansFactoryImpl().createBool();
				item.fromPNML(type, idr);

				item.setContainerVariableDecl(this);

				continue;
			}// end if

			if (type.getLocalName().equals("cyclicenumeration")) {
				CyclicEnumeration item;
				item = new CyclicEnumerationsFactoryImpl()
						.createCyclicEnumeration();
				item.fromPNML(type, idr);

				item.setContainerVariableDecl(this);

				continue;
			}// end if

			if (type.getLocalName().equals("dot")) {
				Dot item;
				item = new DotsFactoryImpl().createDot();
				item.fromPNML(type, idr);

				item.setContainerVariableDecl(this);

				continue;
			}// end if

			if (type.getLocalName().equals("finiteenumeration")) {
				FiniteEnumeration item;
				item = new FiniteEnumerationsFactoryImpl()
						.createFiniteEnumeration();
				item.fromPNML(type, idr);

				item.setContainerVariableDecl(this);

				continue;
			}// end if

			if (type.getLocalName().equals("finiteintrange")) {
				FiniteIntRange item;
				item = new FiniteIntRangesFactoryImpl().createFiniteIntRange();
				item.fromPNML(type, idr);

				item.setContainerVariableDecl(this);

				continue;
			}// end if

			if (type.getLocalName().equals("natural")) {
				Natural item;
				item = new IntegersFactoryImpl().createNatural();
				item.fromPNML(type, idr);

				item.setContainerVariableDecl(this);

				continue;
			}// end if

			if (type.getLocalName().equals("positive")) {
				Positive item;
				item = new IntegersFactoryImpl().createPositive();
				item.fromPNML(type, idr);

				item.setContainerVariableDecl(this);

				continue;
			}// end if

			if (type.getLocalName().equals("integer")) {
				HLInteger item;
				item = new IntegersFactoryImpl().createHLInteger();
				item.fromPNML(type, idr);

				item.setContainerVariableDecl(this);

				continue;
			}// end if

		}

	}

	/**
	 * -
	 */
	public boolean validateOCL(DiagnosticChain diagnostics) {

		TermsValidator val = new TermsValidator();
		boolean retour = true;

		if (getSort() != null) {
			retour &= getSort().validateOCL(diagnostics);
		}

		retour &= val.validate(this, diagnostics, null);
		return retour;

	}
} // VariableDeclImpl
